'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

class Throttle {
    /**
     * Constructor
     */
    constructor(configuration) {
        this.configuration = {
            throttle: 15,
            banTime: 5,
        };
        this.connectionsByIp = new Map();
        this.bannedIps = new Map();
        this.configuration = {
            ...this.configuration,
            ...configuration,
        };
    }
    /**
     * Throttle requests
     * @private
     */
    throttle(ip) {
        if (!this.configuration.throttle) {
            return false;
        }
        const bannedAt = this.bannedIps.get(ip) || 0;
        if (Date.now() < (bannedAt + (this.configuration.banTime * 60 * 1000))) {
            return true;
        }
        this.bannedIps.delete(ip);
        // add this connection try to the list of previous connections
        const previousConnections = this.connectionsByIp.get(ip) || [];
        previousConnections.push(Date.now());
        // calculate the previous connections in the last minute
        const previousConnectionsInTheLastMinute = previousConnections
            .filter(timestamp => timestamp + (60 * 1000) > Date.now());
        this.connectionsByIp.set(ip, previousConnectionsInTheLastMinute);
        if (previousConnectionsInTheLastMinute.length > this.configuration.throttle) {
            this.bannedIps.set(ip, Date.now());
            return true;
        }
        return false;
    }
    /**
     * onConnect hook
     * @param data
     */
    onConnect(data) {
        const { request } = data;
        // get the remote ip address
        const ip = request.headers['x-real-ip']
            || request.headers['x-forwarded-for']
            || request.socket.remoteAddress
            || '';
        // throttle the connection
        return this.throttle(ip) ? Promise.reject() : Promise.resolve();
    }
}

exports.Throttle = Throttle;
//# sourceMappingURL=hocuspocus-throttle.cjs.map
